@@ -13,19 +13,19 @@ class StandardFunction:
 
     @staticmethod
     def res(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         return np.linalg.norm(param_dict["data_vector"], axis=1).reshape(-1, 1)
 
     @staticmethod
     def max(param_dict, absolute=False):
-        '''
+        """
         :param param_dict:
         :param absolute:
         :return:
-        '''
+        """
         data_vector = np.abs(param_dict['data_vector']) if absolute else param_dict['data_vector']
         maximum = np.max(data_vector)
 
@@ -33,11 +33,11 @@ class StandardFunction:
 
     @staticmethod
     def max_in_row(param_dict):
-        '''
+        """
         :param param_dict:
         :param absolute:
         :return:
-        '''
+        """
 
         data_vector = param_dict['data_vector']
         assert len(data_vector.shape) == 2
@@ -46,69 +46,69 @@ class StandardFunction:
 
     @staticmethod
     def argmax(param_dict):
-        '''
+        """
         :param param_dict:
         :param absolute:
         :return:
-        '''
+        """
         data_vector = np.abs(param_dict['data_vector'])
         index_of_maximum = np.argmax(data_vector)
         return index_of_maximum
 
     @staticmethod
     def minimum(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         minimum = np.min(param_dict['data_vector'])
 
         return minimum
 
     @staticmethod
     def multiplication(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.multiply(data_vector_1, data_vector_2)
 
     @staticmethod
     def abs(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vec = param_dict['data_vector']
         return np.abs(data_vec)
 
     @staticmethod
     def transform_2_origin(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vec = param_dict['data_vector']
         return data_vec - data_vec[0]
 
     @staticmethod
     def at_idx(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         index = param_dict["index"]
         data_vector = param_dict["data_vector"]
         return data_vector[index]
 
     @staticmethod
     def linspace(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         start = param_dict["start"]
         stop = param_dict["stop"]
         num = param_dict["num"]
@@ -117,69 +117,69 @@ class StandardFunction:
 
     @staticmethod
     def subtraction(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.subtract(data_vector_1, data_vector_2)
 
     @staticmethod
     def addition(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.add(data_vector_1, data_vector_2)
 
     @staticmethod
     def divide(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.divide(data_vector_1, data_vector_2)
 
     @staticmethod
     def row_sum(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         mat = param_dict["matrix"]
         return np.sum(mat, axis=1)
 
     @staticmethod
     def abs_subtraction(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.abs(np.subtract(data_vector_1, data_vector_2))
 
     @staticmethod
     def abs_addition(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         return np.abs(np.add(data_vector_1, data_vector_2))
 
     @staticmethod
     def abs_subtraction_res(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         data_vector_1 = param_dict["data_vector_1"]
         data_vector_2 = param_dict["data_vector_2"]
         rel_dist = []
@@ -190,11 +190,22 @@ class StandardFunction:
         return np.abs(rel_dist)
 
     @staticmethod
-    def ccdf_weibull(param_dict):
-        '''
+    def time_of_first_negative(param_dict):
+        """
         :param param_dict:
         :return:
-        '''
+        """
+        data_vector = param_dict["data_vector"]
+        time_array = param_dict["time"]
+        time_where_data_vector_less_zero = time_array[(np.where(data_vector < 0))]
+        return time_where_data_vector_less_zero[0] if len(time_where_data_vector_less_zero) != 0 else np.inf
+
+    @staticmethod
+    def ccdf_weibull(param_dict):
+        """
+        :param param_dict:
+        :return:
+        """
         lambda_ = param_dict["lambda"]
         k = param_dict["k"]
         x = param_dict["x"]
@@ -202,7 +213,7 @@ class StandardFunction:
 
     @staticmethod
     def ccdf_sigmoid(param_dict):
-        '''
+        """
 
         :param param_dict:
         :return:
@@ -210,7 +221,7 @@ class StandardFunction:
         Logistic function
         https://en.wikipedia.org/wiki/Logistic_function
 
-        '''
+        """
         k = param_dict["k"]
         x0 = param_dict["x0"]
         x = param_dict["x"]
@@ -219,11 +230,11 @@ class StandardFunction:
 
     @staticmethod
     def cfc(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
         :return:
-        '''
+        """
         assert ('time' in param_dict)
         assert (len(param_dict['time']) >= 2)
 
@@ -238,11 +249,11 @@ class StandardFunction:
 
     @staticmethod
     def HIC15_AIS3(param_dict):
-        '''
+        """
         :param param_dict:
         :param units:
         :return:
-        '''
+        """
         injuryvalue = param_dict["injuryvalue"]
         offset = param_dict["offset"]
         divide = param_dict["divide"]
@@ -252,11 +263,11 @@ class StandardFunction:
 
     @staticmethod
     def BRIC_AIS3(param_dict):
-        '''
+        """
         :param param_dict:
         :param units:
         :return:
-        '''
+        """
         injuryvalue = param_dict["injuryvalue"]
         divide = param_dict["divide"]
         power = param_dict["power"]
@@ -265,10 +276,10 @@ class StandardFunction:
 
     @staticmethod
     def central_differences(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         v = param_dict['data_vector_1'].flatten()
         time = param_dict['data_vector_2']
         a = np.gradient(v, np.squeeze(time))
@@ -277,12 +288,12 @@ class StandardFunction:
 
     @staticmethod
     def tibia_index(param_dict, units):
-        '''
+        """
 
         :param param_dict:
         :param units:
         :return:
-        '''
+        """
         mx = param_dict['Mx'] / ((units.meter() ** 2) / (units.second() ** 2))
         my = param_dict['My'] / ((units.meter() ** 2) / (units.second() ** 2))
         fz = param_dict['Fz'] / (units.meter() / (units.second() ** 2))
@@ -295,20 +306,22 @@ class StandardFunction:
         return ti
 
     @staticmethod
-    def NIC(param_dict, units):
-        '''
-
-        :param param_dict:
+    def NIC(a_t1, a_head, time_, units):
+        """
+        :param a_head:
+        :param a_t1:
+        :param time_:
         :param units:
         :return:
-        '''
-        a_t1 = param_dict['a_T1'].flatten()
-        a_head = param_dict['a_head'].flatten()
+        """
+
+        a_t1 = a_t1.flatten()
+        a_head = a_head.flatten()
         a_t1 /= units.meter() / (units.second() ** 2)  # a_t1 in [m/s^2]
         a_head /= units.meter() / (units.second() ** 2)  # a_head in [m/s^2]
         a_rel = a_t1 - a_head
 
-        t = param_dict['time'].flatten() / units.second()  # t in [s]
+        t = time_.flatten() / units.second()  # t in [s]
         v_rel = cumtrapz(a_rel, t, initial=0)  # integral
 
         return_value_nic = 0.2 * a_rel + v_rel ** 2
@@ -318,7 +331,7 @@ class StandardFunction:
 
     @staticmethod
     def HIC_15(param_dict, units, flag=True):
-        '''
+        """
         time vector in ms
         a_res in mm/s²
 
@@ -330,7 +343,7 @@ class StandardFunction:
         :param flag(HIC15/HIC36):
 
         :return:
-        '''
+        """
         t = param_dict['time'].flatten() / units.second()  # t in [s]
         a_res = param_dict['a_res'].flatten()
         a_res /= units.meter() / (units.second() ** 2)  # a_res in [m/s^2]
@@ -365,25 +378,25 @@ class StandardFunction:
 
     @staticmethod
     def find_index(value, time_history_list, units):
-        '''
+        """
         :param value:
         :param time_history_list:
         :param units:
         :return:
-        '''
+        """
         time_hist_array = np.asarray(time_history_list)
         return (np.abs(time_hist_array - (float(value) * units.second()))).argmin()
 
 
     @staticmethod
     def object_strain_stress_percentile(param_dict):
-        '''
+        """
         only one value possible to return
 
         :param param_dict:
 
         :return:
-        '''
+        """
         part_ids = param_dict["object_data"]["part_ids"]
         part_data = param_dict["object_data"]["part_data"]
         part_idx = param_dict["object_data"]["part_idx"]
@@ -439,17 +452,17 @@ class StandardFunction:
 
     @staticmethod
     def object_strain_stress_hist(param_dict):
-        '''
+        """
 
         :param param_dict:
         :param units:
 
         :return:
-        '''
-        '''
+        """
+        """
         only one value possible to return
         maybe some visualisation possible?!?
-        '''
+        """
         part_ids = param_dict["object_data"]["part_ids"]
         part_data = param_dict["object_data"]["part_data"]
         part_idx = param_dict["object_data"]["part_idx"]
@@ -488,13 +501,13 @@ class StandardFunction:
 
     @staticmethod
     def forman_criteria(param_dict):
-        '''
+        """
 
         :param param_dict:
         :param units:
 
         :return histogram probability broken ribs:
-        '''
+        """
         part_ids = param_dict["object_data"]["part_ids"]
         part_data = param_dict["object_data"]["part_data"]
         part_idx = param_dict["object_data"]["part_idx"]
@@ -570,11 +583,11 @@ class StandardFunction:
 
     @staticmethod
     def object_stress_strain_elems_max(param_dict):
-        '''
+        """
 
         :param param_dict:
         :return:
-        '''
+        """
 
         part_ids = param_dict["object_data"]["part_ids"]
         part_data = param_dict["object_data"]["part_data"]
@@ -604,11 +617,11 @@ class StandardFunction:
 
     @staticmethod
     def time_from_object(param_dict):
-        '''
+        """
 
         :param param_dict:
         :return:
-        '''
+        """
 
         return param_dict["object_data"]["time"]
 
@@ -617,10 +630,10 @@ class StandardFunction:
 
     @staticmethod
     def csdm(param_dict):
-        '''
+        """
         :param param_dict:
         :return:
-        '''
+        """
         limit = param_dict[PluginsParamDictDef.LIMIT]
 
         part_ids = param_dict["object_data"]["part_ids"]
@@ -659,12 +672,12 @@ class StandardFunction:
 
     @staticmethod
     def bric(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
 
         :return:
-        '''
+        """
         r_vel = param_dict["r_vel"] * units.second()
         crit_rx_velocity = param_dict["crit_rx_velocity"]  # [rad/s]
         crit_ry_velocity = param_dict["crit_ry_velocity"]  # [rad/s]
@@ -677,12 +690,12 @@ class StandardFunction:
 
     @staticmethod
     def uBRIC(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
 
         :return:
-        '''
+        """
         r_vel = param_dict["r_vel"] * units.second()
         r_acc = param_dict["r_acc"] * (units.second() ** 2)
 
@@ -711,12 +724,12 @@ class StandardFunction:
 
     @staticmethod
     def vc(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
 
         :return:
-        '''
+        """
         scfa = param_dict['scaling_factor']
         defconst = param_dict['deformation_constant']
         y = param_dict['y'] / units.meter()
@@ -741,12 +754,12 @@ class StandardFunction:
 
     @staticmethod
     def nij(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
 
         :return:
-        '''
+        """
         force_x = param_dict['force_x'] / (units.meter() / (units.second() ** 2))
         force_z = param_dict['force_z'] / (units.meter() / (units.second() ** 2))
         moment_y = param_dict['moment_y'] / ((units.meter() ** 2) / (units.second() ** 2))
@@ -779,11 +792,11 @@ class StandardFunction:
 
     @staticmethod
     def a3ms(param_dict, units):
-        '''
+        """
         :param param_dict:
         :param units:
         :return:
-        '''
+        """
 
         time = param_dict['time'].flatten()  # t in [s]
         a_res = param_dict['a_res'].flatten()
