@@ -3,12 +3,13 @@ import functools
 import numpy as np
 
 from ..utils.constants import LOGConstants, TestConstants, JsonConstants
+import copy
 
 
 class BinoutData(object):
 
     def __init__(self, binout, logger, dynasaur_definitions, name):
-        '''
+        """
         Initialization/constructor
 
         :param: binout
@@ -17,7 +18,7 @@ class BinoutData(object):
         :param: name (binout name)
 
         :return:
-        '''
+        """
 
         self._binout = binout
         self._logger = logger
@@ -64,12 +65,12 @@ class BinoutData(object):
         :return: inteprolated time vector
         """
 
-        if self._dynasaur_definitions.get_units().second() == 1000: # means ms
-            end_time_ = np.round(time_[-1] - time_[0])   # assumed ms
+        if self._dynasaur_definitions.get_units().second() == 1000:  # means ms
+            end_time_ = np.round(time_[-1] - time_[0])  # assumed ms
             assert (time_[0] < 0.02)
-        elif self._dynasaur_definitions.get_units().second() == 1: # means s
+        elif self._dynasaur_definitions.get_units().second() == 1:  # means s
             end_time_ = np.round(time_[-1] - time_[0], 3)
-            #TODO: make assert even if the condition satisfied
+            # TODO: make assert even if the condition satisfied
             # assert (time_[0] < 0.00001)
         else:
             assert False
@@ -78,7 +79,7 @@ class BinoutData(object):
         # https://stackoverflow.com/questions/3844801/check-if-all-elements-in-a-list-are-identical
         # https://numpy.org/doc/stable/reference/generated/numpy.allclose.html
         time_diff = np.diff(time_)
-        if(np.allclose(time_diff, np.tile([time_diff[0]], len(time_diff)))):    
+        if (np.allclose(time_diff, np.tile([time_diff[0]], len(time_diff)))):
             return time_
 
         time_interp = np.linspace(time_[0], end_time_, len(time_))
@@ -110,11 +111,15 @@ class BinoutData(object):
                 array.append(np.where(np.logical_not(logic_intersection)))
                 indices = np.where(np.logical_not(logic_intersection))
                 if indices[0].size != 0:
-                    insert_indices = np.append(insert_indices, indices[0] + len(ids[0]) * i - np.arange(len_indices, len_indices + len(indices[0])))
+                    insert_indices = np.append(insert_indices, indices[0] + len(ids[0]) * i - np.arange(len_indices,
+                                                                                                        len_indices + len(
+                                                                                                            indices[
+                                                                                                                0])))
                     ind = np.append(ind, indices[0] + len(ids[0]) * i)
                     len_indices += len(indices[0])
 
-        available_channels = [value for value in self.__class__.DATA_CHANNEL_TYPES if value in self._binout.read(*args_)]
+        available_channels = [value for value in self.__class__.DATA_CHANNEL_TYPES if
+                              value in self._binout.read(*args_)]
 
         for key in available_channels:
             args_temp = args_ + [key]
@@ -125,13 +130,13 @@ class BinoutData(object):
 
             # check if all ids "survived"
             if len(type_data.shape) == 1:
-                if not isinstance(type_data[0], tuple):     # case if only one data point available
+                if not isinstance(type_data[0], tuple):  # case if only one data point available
                     type_data = type_data[:self._time_interp.shape[0]].reshape(-1, 1)
             else:
                 type_data = type_data[:self._time_interp.shape[0], :]
 
-            if len(insert_indices) != 0:             # Deleted elements should only be possible for elements
-                assert(self._name == "elout")
+            if len(insert_indices) != 0:  # Deleted elements should only be possible for elements
+                assert (self._name == "elout")
                 flatted_data_array = list(sum(type_data, ()))
 
                 zeros = np.zeros(len(insert_indices))
@@ -170,7 +175,7 @@ class BinoutData(object):
             self._ids = np.array(self._binout.read(self._name, self.__class__.ids_name))
             self._read_data_types()
 
-        assert(len(self._ids.shape) == 1)
+        assert (len(self._ids.shape) == 1)
 
     def _set_defined_types(self, dynasaur_definitions):
         """
@@ -300,12 +305,12 @@ class BinoutData(object):
                               ". Plese check your def file!")
 
     def _check_id_in_binout(self, binout_name):
-        '''
+        """
         :param: binout name
 
         :return: True or False
-        '''
-        #TODO: Maybe check if the key is 0(null)
+        """
+        # TODO: Maybe check if the key is 0(null)
         if binout_name == "_energy_global":
             return True, "temp"
         ids_list = []
@@ -314,12 +319,12 @@ class BinoutData(object):
             return True, "temp"
         if self._name == "elout":
             return True, "temp"
-            #keys = self._binout.read(self._name)
-            #ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
+            # keys = self._binout.read(self._name)
+            # ids_list = np.concatenate([self._binout.read(self._name, elem_name, "ids")[0] if elem_name != "solid" else
             #                           self._binout.read(self._name, elem_name, "ids") for elem_name in keys])
         else:
             ids_list = self._binout.read(self._name, "ids")
-        temp_list = []
+
         for sec in dyn_def_key:
             temp_list = list(
                 map(functools.partial(BinoutData.map_help_function, binout_name, ids_list), dyn_def_key[sec]))
@@ -331,6 +336,13 @@ class BinoutData(object):
 
     @staticmethod
     def map_help_function(binout_name, ids_list, id_):
+        """
+
+        :param binout_name:
+        :param ids_list:
+        :param id_:
+        :return:
+        """
         if binout_name == TestConstants.CONTACT:
             master_slave = id_[-1]
             id_for_loop = int(id_[:-1])
@@ -341,11 +353,11 @@ class BinoutData(object):
             return id_
 
     def _check_negative_intersection(self, elements):
-        '''
+        """
         :param: elements
 
         :return: True or False
-        '''
+        """
         # only necessary functions
         negative_intersection = [val for val in self._defined_types if val not in elements]
         if len(negative_intersection) != 0:
@@ -356,35 +368,21 @@ class BinoutData(object):
         return True
 
     def get_data_of_defined_json(self, json_object, data_offsets):
-        '''
+        """
         :param: json object
         :param: data offsets
 
         :return: data array between data offset and date delta t
-        '''
+        """
         ids = self.get_channels_ids_object_name(json_object[JsonConstants.ID_UPPER_CASE], self._name)
 
-        if (len(ids) == 0):
+        if len(ids) == 0:
             if "ID" in json_object:
-                self._logger.emit(LOGConstants.ERROR[0], "Missing ID in the input data with identifier: " + json_object["ID"])
+                self._logger.emit(LOGConstants.ERROR[0],
+                                  "Missing ID in the input data with identifier: " + json_object["ID"])
 
             return
 
-        array_definition = json_object[JsonConstants.ARRAY]
-
-        if array_definition[0].split(',')[0].strip(' (') == "all":
-            converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in enumerate("ids")]
-        else:
-            # processing data array
-            converted_tuples = [(int(tuple_string.split(',')[0].strip(' (')), tuple_string.split(',')[1].strip(' )'))
-                                for tuple_string
-                                in array_definition]
-
-        data_array = None
-        for tpl in converted_tuples:
-            d = self.get_measurement_channel(id_=ids[tpl[0]], channel_name=tpl[1])
-            data_array = d if data_array is None else np.append(data_array, d, axis=1)
-
         data_offset = 0
         data_delta_t = -1
         for (t, offset, delta_t) in data_offsets:
@@ -392,7 +390,26 @@ class BinoutData(object):
                 data_offset = offset
                 data_delta_t = delta_t
 
-        return data_array[data_offset:data_delta_t]
+        array_definition = json_object[JsonConstants.ARRAY]
+        if array_definition[0].split(',')[0].strip(' (') == "all":
+            converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in
+                                enumerate("ids")]
+        else:
+            # processing data array
+            converted_tuples = [(int(tuple_string.split(',')[0].strip(' (')), tuple_string.split(',')[1].strip(' )'))
+                                for tuple_string
+                                in array_definition]
+
+        data_array = None
+        for tpl in converted_tuples:
+            d = copy.copy(self.get_measurement_channel(id_=ids[tpl[0]], channel_name=tpl[1]))
+            if tpl[1] == "time":
+                d -= d[data_offset, 0]
+            data_array = d[data_offset:data_delta_t] if data_array is None else np.append(data_array,
+                                                                                          d[data_offset:data_delta_t],
+                                                                                          axis=1)
+
+        return data_array
 
     def get_measurement_channel(self, id_, channel_name):
         """
@@ -406,7 +423,7 @@ class BinoutData(object):
             return self._time_interp.reshape(-1, 1)
         if np.issubdtype(self._ids.dtype, np.number):
             data_index = np.where(int(id_) == self._ids)[0]
-        else:  # madymo case
+        else:  # madymo case ... ids are not numeric
             data_index = np.where(id_ == self._ids)[0]
 
         if len(data_index) == 0:
@@ -414,7 +431,7 @@ class BinoutData(object):
             exit()
 
         self._logger.emit(LOGConstants.DATA_PLUGIN[0], 'read id ' + str(id_) + ' from channel name: ' + channel_name)
-        assert(len(data_index) >= 1)
+        assert (len(data_index) >= 1)
 
         if channel_name not in self._data.keys():
             self._logger.emit(LOGConstants.ERROR[0], str(id_) + ' has no data with the identifier : ' + channel_name)
