@@ -35,11 +35,11 @@ class Units(object):
 
 class DefintionObject(object):
     def __init__(self, oid):
-        '''
+        """
         Init function / constructor
         :param oid:
         :return:
-        '''
+        """
         self._oid = oid
         self._parts = {}
         self._elements = {}
@@ -60,19 +60,19 @@ class DefintionObject(object):
         return sorted(self._elements)
 
 
-
 class DynasaurDefinitions:
     # create the object container
     def __init__(self, logger):
-        '''
+        """
         constructor
 
         :param logger:
         :return:
-        '''
+        """
         self._title = ''
         self._objects = {}
-        self._logger = logger
+        self.logger = logger
+        self._logger = self.logger
         self._info = []
 
         # set all class members
@@ -94,10 +94,10 @@ class DynasaurDefinitions:
         self._units = Units()
 
     def get_param_dict_from_command(self, command):
-        '''
+        """
         :param command:
         :return dictionary on the command
-        '''
+        """
         if 'visualization' in command:
             d = command
             d[PluginsParamDictDef.DYNASAUR_JSON] = self.get_data_vis(command['visualization'])
@@ -111,23 +111,22 @@ class DynasaurDefinitions:
             print("[ERROR] Command not in command list")
             return
 
-
     def get_units(self):
-        '''
+        """
         get units
 
         :param:
         :return units:
-        '''
+        """
         return self._units
 
     def get_criteria(self, key):
-        '''
+        """
         get criteria
 
         :param key:
         :return criteria:
-        '''
+        """
         if key not in self._criteria.keys() or len(self._criteria) == 0:
             self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[6] + "\"" + key + "\"")
             exit("Exiting, check your def file")
@@ -135,27 +134,26 @@ class DynasaurDefinitions:
         return self._criteria[key]
 
     def get_data_vis(self, key):
-        '''
+        """
         get code
 
         :param:
         :return code:
-        '''
+        """
         if key not in self._data_vis.keys() or len(self._data_vis) == 0:
             self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[7] + "\"" + key + "\"")
             exit("Exiting, check your def file")
         return self._data_vis[key]
 
-
     def get_ids_from_name(self, name, data_container, plugin_name):
-        '''
+        """
         get ids from given name
 
         :param name:
         :param data_container:
         :param plugin_name:
         :return dict(name):
-        '''
+        """
         d = {}
         if data_container == "nodout":
             d = self._node
@@ -188,14 +186,13 @@ class DynasaurDefinitions:
 
         return d[name]
 
-
     def get_defined_objects_containing_parts(self, part_ids):
-        '''
+        """
         get defined object containing parts
 
         :param part_ids:
         :return list_defined_objects:
-        '''
+        """
         list_defined_objects = []
         for tmp_object_name in sorted(self._objects):
             tmp_part_ids = list(self._objects[tmp_object_name].get_parts())
@@ -209,12 +206,12 @@ class DynasaurDefinitions:
         return list_defined_objects
 
     def get_defined_objects_containing_all_parts(self, part_ids):
-        '''
+        """
         get defined object
 
         :param part_ids:
         :return list_defined_objects:
-        '''
+        """
         list_defined_objects = []
         for tmp_object_name in sorted(self._objects):
             tmp_part_ids = list(self._objects[tmp_object_name].get_parts())
@@ -227,13 +224,12 @@ class DynasaurDefinitions:
 
         return list_defined_objects
 
-    # param is a list of part_ids
     def define_dynasaur_everything(self, part_ids):
-        '''
+        """
         define dynasaur everything
-        :param part_ids:
+        :param part_ids:  list of part_ids
         :return:
-        '''
+        """
 
         # create an Everything object
         name = "Dynasaur Everything"
@@ -243,13 +239,13 @@ class DynasaurDefinitions:
         self._objects[name].set_parts(part_ids)
 
     def _get_all_data_types_from_json(self, d, ls):
-        '''
+        """
         get all data types
 
         :param d:
         :param ls:
         :return d[TYPE]:
-        '''
+        """
 
         for key in d.keys():
             if key is None:
@@ -266,12 +262,12 @@ class DynasaurDefinitions:
                 return d[JsonConstants.TYPE]
 
     def get_required_datatypes(self, plugin_name):
-        '''
+        """
         get required datatype
 
         :param plugin_name:
         :return ls:
-        '''
+        """
         ls = []
         if DefinitionConstants.CRITERIA == plugin_name:
             self._get_all_data_types_from_json(self._criteria, ls)
@@ -282,31 +278,31 @@ class DynasaurDefinitions:
         return ls
 
     def get_parts_by_object_containing_part_ids(self, tmp_object, part_ids):
-        '''
+        """
         get parts by object containing part ids
 
         :param tmp_object:
         :param part_ids:
         :return parts by object:
-        '''
+        """
         return [val for val in part_ids if val in self._objects[tmp_object].get_parts()]
 
     def get_info(self):
-        '''
+        """
         get info
 
         :param:
         :return info:
-        '''
+        """
         return self._info
 
     def _set_contact(self, json_object):
-        '''
+        """
         set contact object type
 
         :param json_object:
         :return:
-        '''
+        """
         name = json_object[JsonConstants.NAME]
 
         if JsonConstants.ID in json_object:
@@ -333,12 +329,12 @@ class DynasaurDefinitions:
 
 
     def __set_object(self, json_object):
-        '''
+        """
         set object
 
         :param json_object:
         :return:
-        '''
+        """
         name = json_object[JsonConstants.NAME]
         self._objects[name] = DefintionObject(name)
         if JsonConstants.ID in json_object:
@@ -359,12 +355,12 @@ class DynasaurDefinitions:
                 self._objects[name].add_element(i)
 
     def _parse_objects(self, json_objects):
-        '''
+        """
         parse json objects and call setter
 
         :param json_object:
         :return:
-        '''
+        """
         for json_object in json_objects[DefinitionConstants.OBJECTS]:
 
             if json_object[JsonConstants.TYPE] == ObjectConstantsForData.ELEMENTOBJECT:
@@ -394,12 +390,12 @@ class DynasaurDefinitions:
                                   json_object[JsonConstants.TYPE] + LoggerWARNING.print_statements[1])
 
     def _set_unit(self, json_object):
-        '''
+        """
         set unit object
 
         :param json_object:
         :return:
-        '''
+        """
         for key_name in json_object[DefinitionConstants.UNIT]:
             if key_name == UnitsConstants.TIME:
                 if json_object[DefinitionConstants.UNIT][key_name] == UnitsConstants.SECOND:
@@ -418,34 +414,34 @@ class DynasaurDefinitions:
                     self._units.set_weight(UnitsConstants.WEIGHT_DEFAULT)
 
     def _set_criteria(self, json_object):
-        '''
+        """
         set criteria object
 
         :param json_object:
         :return:
-        '''
+        """
         for criteria in json_object[DefinitionConstants.CRITERIA]:
             body_part = criteria[JsonConstants.PART_OF]
             self._criteria[body_part + "_" + criteria[JsonConstants.NAME]] = criteria
 
     def _set_diagram_visualisation(self, json_object):
-        '''
+        """
         set data visualisation object
 
         :param json_object:
         :return:
-        '''
+        """
         for definition in json_object[DefinitionConstants.DATA_VIS]:
             body_part = definition[JsonConstants.PART_OF]
             self._data_vis[body_part + "_" + definition[JsonConstants.NAME]] = definition
 
     def _set_info(self):
-        '''
+        """
         set info in data visualisation
 
         :param:
         :return:
-        '''
+        """
         info = []
         for key in self._data_vis.keys():
             if JsonConstants.INFO in self._data_vis[key].keys():
@@ -465,12 +461,12 @@ class DynasaurDefinitions:
         self._info = info
 
     def read_def(self, fn):
-        '''
+        """
         read definition file
 
         :param fn:
         :return:
-        '''
+        """
         self._logger.emit(LOGConstants.READ_DYNASAUR_DEF[0], LD.READ % fn)
         if fn is None:
             exit("No definition file")
