@@ -3,19 +3,21 @@ from enum import Enum
 
 import numpy as np
 import time as t
+import copy
+
 
 from ..utils.constants import LOGConstants
 from ..data.data_interface import BinoutData
 
 
 class DEForc(BinoutData):
-    '''
-    '''
+    """
+    """
     DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force', 'displacement', 'resultant_force']
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization i.e. call BinoutData constructor
 
         :param: binout
@@ -23,26 +25,22 @@ class DEForc(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'deforc')
 
 
 class Disbout(BinoutData):
-
     DATA_CHANNEL_TYPES = ['r_dis_axial', 'moment_s', 'rslt_nt', 'r_dis_nt', 't_dir_y', 'axial_rot',
                           's_dir_y', 'r_dis_ns', 'matid', 's_dir_x', 'torsion', 'rslt_ns', 'axial_z', 'mtype',
                           't_dir_x', 'rot_s', 'axial_y', 's_dir_z', 'rot_t', 'rslt_axial', 'moment_t', 'axial_x',
                           't_dir_z']
     ids_name = "nelb"
 
-
     def __init__(self, binout, logger, dynasaur_definitions):
-
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'disbout')
 
 
 class PartDisbout(BinoutData):
-
     DATA_CHANNEL_TYPES = ['r_dis_axial', 'moment_s', 'rslt_nt', 'r_dis_nt', 't_dir_y', 'axial_rot',
                           's_dir_y', 'r_dis_ns', 'matid', 's_dir_x', 'torsion', 'rslt_ns', 'axial_z', 'mtype',
                           't_dir_x', 'rot_s', 'axial_y', 's_dir_z', 'rot_t', 'rslt_axial', 'moment_t', 'axial_x',
@@ -50,7 +48,7 @@ class PartDisbout(BinoutData):
     ids_name = "nelb"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization i.e. call BinoutData constructor
 
         :param: binout
@@ -58,11 +56,9 @@ class PartDisbout(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'disbout')
 
-
-
     def get_channels_ids_object_name(self, object_name, plugin_name):
         """
         :return: time array
@@ -81,36 +77,30 @@ class PartDisbout(BinoutData):
 
         return d
 
-
     def get_data_of_defined_json(self, json_object, data_offsets):
-        '''
+        """
         :param: json object
         :param: data offsets
 
         :return: data array between data offset and date delta t
-        '''
+        """
         from ..utils.constants import JsonConstants
 
         part_ids = self.get_channels_ids_object_name(json_object[JsonConstants.ID_UPPER_CASE], self._name)
         part_ids_to_element_ids = self.get_element_ids_from_part_ids(part_ids)
 
-        assert(len(part_ids_to_element_ids) != 0)
+        assert (len(part_ids_to_element_ids) != 0)
         array_definition = json_object[JsonConstants.ARRAY]
 
         if array_definition[0].split(',')[0].strip(' (') == "all":
-            converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in enumerate("ids")]
+            converted_tuples = [(index, array_definition[0].split(',')[1].strip(' )')) for index, id_ in
+                                enumerate("ids")]
         else:
             # processing data array
             converted_tuples = [(int(tuple_string.split(',')[0].strip(' (')), tuple_string.split(',')[1].strip(' )'))
                                 for tuple_string
                                 in array_definition]
 
-        data_array = None
-        for tpl in converted_tuples:
-            for element_id in part_ids_to_element_ids[part_ids[tpl[0]]]:
-                d = self.get_measurement_channel(id_=element_id, channel_name=tpl[1])
-                data_array = d if data_array is None else np.append(data_array, d, axis=1)
-
         data_offset = 0
         data_delta_t = -1
         for (t, offset, delta_t) in data_offsets:
@@ -118,6 +108,14 @@ class PartDisbout(BinoutData):
                 data_offset = offset
                 data_delta_t = delta_t
 
+        data_array = None
+        for tpl in converted_tuples:
+            for element_id in part_ids_to_element_ids[part_ids[tpl[0]]]:
+                d = copy.copy(self.get_measurement_channel(id_=element_id, channel_name=tpl[1]))
+                if tpl[1] == "time":
+                    d -= d[data_offset - 1]
+                data_array = d[data_offset:data_delta_t] if data_array is None else np.append(data_array, d[data_offset:data_delta_t], axis=1)
+
         return data_array[data_offset:data_delta_t]
 
 
@@ -134,13 +132,13 @@ class EloutIndex(Enum):
 
     @staticmethod
     def translate_element(name):
-        '''
+        """
         Translate element with given name
 
         :param: name
 
         :return EloutIndex(SHELL, SOLID, BEAM):
-        '''
+        """
         name = name.lower()
         if name == "shell":
             return EloutIndex.SHELL
@@ -151,13 +149,13 @@ class EloutIndex(Enum):
 
     @staticmethod
     def translate_strain_stress(name):
-        '''
+        """
         Translate strain or stress with given name
 
         :param: name
 
         :return EloutIndex(STRESS, STRAIN):
-        '''
+        """
         name = name.lower()
         if name == "strain":
             return EloutIndex.STRAIN
@@ -166,18 +164,17 @@ class EloutIndex(Enum):
 
 
 class EloutObject(BinoutData):
-
     DATA_CHANNEL_TYPES = []
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions, volume_path=None):
-        '''
+        """
 
         :param binout:
         :param logger:
         :param dynasaur_definitions:
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'elout')
         self._data_mapping_part_id_to_element_type = {}
         self._data_mapping_element_id_to_part_id = {}
@@ -192,19 +189,19 @@ class EloutObject(BinoutData):
         self._time = None
 
     def get_interpolated_time(self):
-        '''
+        """
         :return: no data interpolation for stress and strain types
-        '''
+        """
         return self._time
 
     def get_data_of_defined_json(self, json_object, data_offset):
-        '''
+        """
 
         :param json_object:
         :param data_offset:
 
         :return dict_data:
-        '''
+        """
 
         strain_stress_idx = EloutIndex.translate_strain_stress(json_object["strain_stress"])
 
@@ -221,7 +218,7 @@ class EloutObject(BinoutData):
         part_data = {}
         part_index = {}
 
-        assert(len(part_ids) > 0)
+        assert (len(part_ids) > 0)
 
         for part_id in part_ids:
             index, data = self.get_part_data(strain_stress_idx, part_id, time_step_indices=time_step_indices)
@@ -238,15 +235,15 @@ class EloutObject(BinoutData):
 
         return {"part_ids": part_ids, "part_data": part_data,
                 "part_idx": part_index, "time_step_indices": time_step_indices,
-                "element_type" : element_type, "part_value": part_volume,
+                "element_type": element_type, "part_value": part_volume,
                 "el_by_part_id_el_id": el_by_part_id_el_id,
                 "time": self.get_interpolated_time()[time_step_indices]}
 
     def _read_volume_data_from_file_volume(self, path_to_volume):
-        '''
+        """
 
         :return:
-        '''
+        """
         if self._file_data_mapping_element_id_to_volume is not None:
             return True
 
@@ -269,11 +266,11 @@ class EloutObject(BinoutData):
         return True
 
     def _init_data_volume(self, data_mapping_part_id_to_element_ids):
-        '''
+        """
 
         :param data_mapping_part_id_to_element_ids:
         :return:
-        '''
+        """
         if len(self._data_mapping_part_id_to_volume) != 0:
             return True
 
@@ -295,31 +292,31 @@ class EloutObject(BinoutData):
         return True
 
     def get_part_volume_by_part_ID(self):
-        '''
+        """
 
         :param part_id:
         :return:
-        '''
+        """
         return self._data_mapping_part_id_to_volume
 
     def get_element_volume_by_part_id_and_element_id(self):
-        '''
+        """
 
         :param part_id:
         :param element_id:
         :return:
-        '''
+        """
         return self._data_mapping_part_id_to_element_id_to_volume
 
     def _append_data(self, index_matrix, data_tensor, strain_stress_type, element_type):
-        '''
+        """
 
         :param index_matrix:
         :param data_tensor:
         :param strain_stress_type:
         :param element_type:
         :return:
-        '''
+        """
         if strain_stress_type not in self._data:
             self._data[strain_stress_type] = {}
 
@@ -334,13 +331,13 @@ class EloutObject(BinoutData):
         self._data[strain_stress_type][element_type][EloutIndex.DATA] = data_tensor
 
     def _append_mapping_part_id_to_element_type(self, index_matrix, strain_stress_type, element_type):
-        '''
+        """
 
         :param index_matrix:
         :param strain_stress_type:
         :param element_type:
         :return:
-        '''
+        """
         if strain_stress_type not in self._data_mapping_part_id_to_element_type:
             self._data_mapping_part_id_to_element_type[strain_stress_type] = {}
 
@@ -354,13 +351,13 @@ class EloutObject(BinoutData):
                 self._data = {}
 
     def _append_mapping_element_id_to_part_id(self, index_matrix, strain_stress_type, elout_elem):
-        '''
+        """
 
         :param index_matrix:
         :param strain_stress_type:
         :param elout_elem:
         :return:
-        '''
+        """
         if strain_stress_type not in self._data_mapping_element_id_to_part_id:
             self._data_mapping_element_id_to_part_id[strain_stress_type] = {}
 
@@ -380,13 +377,12 @@ class EloutObject(BinoutData):
                 self._logger.emit(LOGConstants.ERROR[0], "elout: could not be read")
                 self._data = {}
 
-
     def _append_mapping_part_id_to_element_ids(self, strain_stress_type):
-        '''
+        """
 
         :param strain_stress_type:
         :return:
-        '''
+        """
         if strain_stress_type not in self._data_mapping_element_id_to_part_id:
             return
 
@@ -401,11 +397,11 @@ class EloutObject(BinoutData):
                 self._data_mapping_part_id_to_element_ids[strain_stress_type][part_id].append(element_id)
 
     def _concatenated_ranges(self, ranges_list):
-        '''
+        """
 
         :param ranges_list:
         :return:
-        '''
+        """
         ranges_list = np.array(ranges_list, copy=False)
         base_range = np.arange(1, ranges_list.max() + 1)
         base_range = as_strided(base_range,
@@ -414,39 +410,39 @@ class EloutObject(BinoutData):
         return base_range[base_range <= ranges_list[:, None]]
 
     def _get_data(self, part_id, strain_stress_type):
-        '''
+        """
 
         :param part_id:
         :param strain_stress_type:
         :return:
-        '''
+        """
         element_type = self._data_mapping_part_id_to_element_type[strain_stress_type][part_id]
         return self._data[strain_stress_type][element_type]
 
     def _get_all_part_ids(self):
-        '''
+        """
 
         :return:
-        '''
+        """
         return np.unique([y for x in [list(self._data_mapping_part_id_to_element_type[vals].keys()) for vals in
                                       self._data_mapping_part_id_to_element_type] for y in x])
 
     def _get_part_ids(self, strain_stress_type):
-        '''
+        """
 
         :param strain_stress_type:
         :return:
-        '''
+        """
         return list(self._data_mapping_part_id_to_element_type[strain_stress_type].keys())
 
     def _get_elout_data_and_extend(self, elout_elem, name, extendable_indices):
-        '''
+        """
         get the data from binout and extend the given indices with dummy values
         :param elout_elem:
         :param name:
         :param extendable_indices:
         :return:
-        '''
+        """
         if extendable_indices.size == 0:
             return self._binout.read("elout", elout_elem, name).reshape((-1, 1))
 
@@ -468,10 +464,10 @@ class EloutObject(BinoutData):
         return a[0]
 
     def _info_matrix(self, elout_elem, time, what):
-        '''
+        """
             duplicate all entries of first time entry.
             part id, integration points, element id
-        '''
+        """
         if ((elout_elem == "shell" or elout_elem == "beam") and what == "stress"):
             # ok
             nip = np.tile(self._binout.read(self._name, elout_elem, 'nip')[0], time.shape[0]).flatten()
@@ -507,9 +503,8 @@ class EloutObject(BinoutData):
 
         return (np.concatenate((ids, mat, ipts), axis=1)).astype(int)
 
-
     def _indices_of_destroyed_elements(self, elout_elem, type):
-        '''
+        """
         indices list of destroyed elements over time
         used to insert dummy values [used for padding to full sized matrix
             -> meaning, each element is available over the entire time]
@@ -526,7 +521,7 @@ class EloutObject(BinoutData):
         :param elout_elem:
         :param type:
         :return:
-        '''
+        """
 
         array = []
         insert_indices = np.array([], dtype=int)
@@ -573,9 +568,9 @@ class EloutObject(BinoutData):
         return insert_indices, ind
 
     def _set_nans(self, w_stress, ind):
-        '''
+        """
         set dummy values to NaN (done for deleted elements)
-        '''
+        """
         if ind.size != 0:
             self._logger.emit(LOGConstants.WARNING[0], "Evaluated object contains failed elements!")
             w_stress[ind] = np.tile(np.array([np.NaN]), 3)
@@ -583,12 +578,12 @@ class EloutObject(BinoutData):
     ####################################################################################################################
 
     def _assign_stresses(self, elout_elem):
-        '''
+        """
         calculate stress from the elout_elem
 
         :param elout_elem:
         :return:
-        '''
+        """
 
         if elout_elem != "solid" and elout_elem != "shell" and elout_elem != "beam":
             return
@@ -659,11 +654,11 @@ class EloutObject(BinoutData):
         self._append_mapping_element_id_to_part_id(index_matrix, EloutIndex.STRESS, elout_elem)
 
     def _assign_strains(self, elout_elem):
-        '''
+        """
 
         :param elout_elem:
         :return:
-        '''
+        """
         # check the cases where to reject to read strains (if shells or solids do not have an epsilon component)
         self._logger.emit(LOGConstants.READ_BINOUT[0], ("assign strains for " + elout_elem + " elements"))
 
@@ -701,47 +696,47 @@ class EloutObject(BinoutData):
             eps = np.concatenate((np.insert(
                 self._get_elout_data_and_extend(elout_elem, "lower_eps_xx", insert_indices).flatten(), ind_array,
                 self._get_elout_data_and_extend(elout_elem, "upper_eps_xx", insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_xy",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_xy",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_zx",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_zx",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_xy",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_xy",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_yy",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_yy",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_yz",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_yz",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_zx",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_zx",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_yz",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_yz",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1),
                                   np.insert(self._get_elout_data_and_extend(elout_elem, "lower_eps_zz",
-                                                                             insert_indices).flatten(), ind_array,
+                                                                            insert_indices).flatten(), ind_array,
                                             self._get_elout_data_and_extend(elout_elem, "upper_eps_zz",
-                                                                             insert_indices).flatten()).reshape(-1,
-                                                                                                                1)),
+                                                                            insert_indices).flatten()).reshape(-1,
+                                                                                                               1)),
                                  axis=1)
 
         elif elout_elem == "solid":
@@ -778,10 +773,10 @@ class EloutObject(BinoutData):
         self._append_mapping_element_id_to_part_id(index_matrix, EloutIndex.STRAIN, elout_elem)
 
     def read_binout_data(self):
-        '''
+        """
         function will be called before a plugin controller is instantiated which needs elout data
         :return: True when data is read in, False when no data available
-        '''
+        """
         # data already read
         if len(self._data) != 0:
             return True
@@ -806,7 +801,7 @@ class EloutObject(BinoutData):
         #
         time_lengths = [len(self._binout.read(self._name, elem, 'time').flatten()) for elem in elements]
 
-        assert(all([time_lengths[0] == length for length in time_lengths]))
+        assert (all([time_lengths[0] == length for length in time_lengths]))
 
         self._time = self._binout.read(self._name, elements[0], 'time')
 
@@ -839,54 +834,51 @@ class EloutObject(BinoutData):
         return True
 
     def get_data_mapping_part_i_dto_element_ids(self, strain_stress_type):
-        '''
+        """
 
         :param strain_stress_type:
         :return:
-        '''
+        """
         return self._data_mapping_part_id_to_element_ids[strain_stress_type]
 
     def get_element_type_from_part_id(self, part_id, strain_stress_type):
-        '''
+        """
 
         :param part_id:
         :param strain_stress_type:
         :return:
-        '''
+        """
         return self._data_mapping_part_id_to_element_type[strain_stress_type][part_id]
 
     def get_defined_objects(self):
-        '''
+        """
 
         :return:
-        '''
+        """
         return self._dynasaur_definitions.get_defined_objects_containing_parts(self._get_all_part_ids())
 
-
     def get_part_ids_by_object_name(self, object_name, strain_stress_type):
-        '''
+        """
 
         :param object_name:
         :param strain_stress_type:
         :return:
-        '''
+        """
         return self._dynasaur_definitions.get_parts_by_object_containing_part_ids(object_name,
                                                                                   self._get_part_ids(
                                                                                       strain_stress_type))
 
     def get_element_ids_by_part_id(self, part_id, strain_stress_type):
-        '''
+        """
 
         :param part_id:
         :param strain_stress_type:
         :return:
-        '''
+        """
         return self._data_mapping_part_id_to_element_ids[strain_stress_type][part_id]
 
-
-
     def get_part_data(self, strain_stress_type, part_id, element_id=None, time_step_indices=None):
-        '''
+        """
         description: return filtered index matrix and data tensor over all time steps for a given part_id
             will return all element, part, integration combinations
 
@@ -902,7 +894,7 @@ class EloutObject(BinoutData):
         :param element_id:
         :param time_step_indices:
         :return:
-        '''
+        """
         tmp_data = self._get_data(part_id, strain_stress_type)
 
         if element_id is None:
@@ -910,7 +902,7 @@ class EloutObject(BinoutData):
         else:
             row_index = \
                 np.where((tmp_data[EloutIndex.INDEX][:, 1] == part_id) & (
-                            tmp_data[EloutIndex.INDEX][:, 0] == element_id))[
+                        tmp_data[EloutIndex.INDEX][:, 0] == element_id))[
                     0]
 
         if time_step_indices is None:
@@ -921,12 +913,12 @@ class EloutObject(BinoutData):
         return tmp_data[EloutIndex.INDEX][row_index, :], data
 
     def get_element_type_name(self, element_id, strain_stress_type):
-        '''
+        """
 
         :param element_id:
         :param strain_stress_type:
         :return:
-        '''
+        """
         element_types = []
         for element_type in self._data_mapping_element_id_to_part_id[strain_stress_type].keys():
             if element_id in self._data_mapping_element_id_to_part_id[strain_stress_type][element_type]:
@@ -934,9 +926,8 @@ class EloutObject(BinoutData):
                 element_types.append(self._data_mapping_part_id_to_element_type[strain_stress_type][part_id].name)
         return element_types
 
-
     def get_integration_point_indices_of_part_data_by_element_id(self, index, element_id):
-        '''
+        """
         further filtering by element_id of given results from getPartData()
 
         index and data are return values of getPartData()
@@ -948,12 +939,11 @@ class EloutObject(BinoutData):
         :param index:
         :param element_id:
         :return:
-        '''
+        """
         return np.where(index[:, 0] == element_id)[0]
 
-
     def get_element_ids_of_part_data(self, index):
-        '''
+        """
         parameter uses index matrix of getPartData()
         using this function instead of the data_mappings will enhance performance
 
@@ -961,18 +951,17 @@ class EloutObject(BinoutData):
 
         :param index:
         :return:
-        '''
+        """
         return np.unique(index[:, 0])
 
 
 class Elout(BinoutData):
-
     # applies for beam elements!
     DATA_CHANNEL_TYPES = ['axial', 'shear_s', 'shear_t', 'moment_s', 'moment_t', 'torsion']
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization i.e. call BinoutData constructor
 
         :param: binout
@@ -980,13 +969,13 @@ class Elout(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'elout')
 
 
 class Glstat(BinoutData):
-    '''
-    '''
+    """
+    """
     DATA_CHANNEL_TYPES = ['global_y_velocity', 'internal_energy', 'kinetic_energy', 'percent_increase', 'ts_element',
                           'energy_ratio_wo_eroded', 'spring_and_damper_energy', 'eroded_kinetic_energy',
                           'num_bad_shells', 'energy_ratio', 'external_work', 'time_step', 'global_z_velocity',
@@ -997,7 +986,7 @@ class Glstat(BinoutData):
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization i.e. call BinoutData constructor
 
         :param: binout
@@ -1005,7 +994,7 @@ class Glstat(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'glstat')
 
     def _read_data_types(self):
@@ -1050,8 +1039,8 @@ class Glstat(BinoutData):
 
 
 class Matsum(BinoutData):
-    '''
-    '''
+    """
+    """
     DATA_CHANNEL_TYPES = ['x_momentum', 'y_rbvelocity', 'z_rbvelocity', 'internal_energy', 'kinetic_energy',
                           'max_shell_mass', 'y_momentum', 'mass', 'eroded_kinetic_energy', 'brick_id', 'max_brick_mass',
                           'shell_id', 'eroded_internal_energy', 'z_momentum', 'hourglass_energy',
@@ -1060,7 +1049,7 @@ class Matsum(BinoutData):
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization i.e. call BinoutData constructor
 
         :param: binout
@@ -1068,13 +1057,13 @@ class Matsum(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'matsum')
 
 
 class Nodout(BinoutData):
-    '''
-    '''
+    """
+    """
     DATA_CHANNEL_TYPES = ['rx_velocity', 'ry_velocity', 'rz_velocity', 'rx_displacement', 'ry_displacement',
                           'rz_displacement', 'rx_acceleration', 'ry_acceleration', 'rz_acceleration', 'x_coordinate',
                           'y_coordinate', 'z_coordinate', 'x_displacement', 'y_displacement', 'z_displacement',
@@ -1083,7 +1072,7 @@ class Nodout(BinoutData):
     ids_name = "ids"
 
     def __init__(self, data, logger, dynasaur_definitions):
-        '''
+        """
         Initialization/constructor
 
         :param: binout
@@ -1092,43 +1081,10 @@ class Nodout(BinoutData):
         :param: cody type(MADYMO/LS DYNA)
 
         :return:
-        '''
-        #self._code_type = code_type
+        """
 
         BinoutData.__init__(self, data, logger, dynasaur_definitions, 'nodout')
 
-    # def get_channels_ids_object_name(self, object_name, plugin_name):
-    #     '''
-    #     Get channels ids with given object name and plugin name
-    #
-    #     :param: object_name
-    #     :param: plugin_name
-    #
-    #     :return channel ids:
-    #     '''
-    #     return BinoutData.get_channels_ids_object_name(self, object_name, plugin_name)
-
-    # def get_measurement_channel(self, id, channel_name):
-    #     '''
-    #     Get measurement channel with given id and channel name
-    #
-    #     :param: id
-    #     :param: channel_name
-    #
-    #     :return measurement channel:
-    #     '''
-    #     return BinoutData.get_measurement_channel(self, id, channel_name)
-
-    # def get_time(self):
-    #     '''
-    #     Get time
-    #
-    #     :param:
-    #
-    #     :return time:
-    #     '''
-    #     return BinoutData.get_interpolated_time(self)
-
 
 class RCForc(BinoutData):
     DATA_CHANNEL_TYPES = ['x_moment', 'y_moment', 'z_moment', 'x_force', 'y_force', 'z_force', 'tie_count', 'mass',
@@ -1137,7 +1093,7 @@ class RCForc(BinoutData):
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization/constructor
 
         :param: binout
@@ -1145,16 +1101,16 @@ class RCForc(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, "rcforc")
 
     def get_measurement_channel(self, id_, channel_name):
-        '''
+        """
 
         :param id:
         :param channel_name:
         :return:
-        '''
+        """
         if channel_name == 'time':
             return self._time.reshape(-1, 1)
 
@@ -1184,13 +1140,13 @@ class RCForc(BinoutData):
 
 
 class SBTout(BinoutData):
-    '''
-    '''
+    """
+    """
     DATA_CHANNEL_TYPES = ['belt_length', 'belt_force']
     ids_name = "belt_ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization/constructor
 
         :param: binout
@@ -1198,20 +1154,20 @@ class SBTout(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, "sbtout")
 
 
 class Secforc(BinoutData):
-    '''
-    '''
-    DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force',  'x_moment', 'y_moment', 'z_moment',
-                          'x_centroid', 'y_centroid', 'z_centroid', 'total_force', 'total_moment',  'area']
-                            #'total_force', 'total_moment',  'area'
+    """
+    """
+    DATA_CHANNEL_TYPES = ['x_force', 'y_force', 'z_force', 'x_moment', 'y_moment', 'z_moment',
+                          'x_centroid', 'y_centroid', 'z_centroid', 'total_force', 'total_moment', 'area']
+    # 'total_force', 'total_moment',  'area'
     ids_name = "ids"
 
     def __init__(self, binout, logger, dynasaur_definitions):
-        '''
+        """
         Initialization/constructor
 
         :param: binout
@@ -1219,14 +1175,9 @@ class Secforc(BinoutData):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         BinoutData.__init__(self, binout, logger, dynasaur_definitions, 'secforc')
 
     def __get_indices_of_ids(self, ids):
         tmp_ids = self._ids.tolist()
         return [tmp_ids.index(val) for val in tmp_ids if val in ids]
-
-
-
-
-
