@@ -9,7 +9,7 @@ from ..utils.constants import DefinitionConstants, OutputStringForPlugins, Plugi
 class CriteriaController(Plugin, PluginInterface):
     def __init__(self, calculation_procedure_def_file, object_def_file, data_source, user_function_object=None,
                  volume_def_file=None, code_type="LS-DYNA"):
-        '''
+        """
         Initialization i.e. call Plugin constructor
         :param: root
         :param: calculation_procedure_def_file
@@ -20,7 +20,7 @@ class CriteriaController(Plugin, PluginInterface):
         :param: volume_def_file
 
         :return:
-        '''
+        """
         Plugin.__init__(self, path_to_def_file=calculation_procedure_def_file, path_def_file_id=object_def_file,
                         data_source=data_source, volume_path=volume_def_file, user_function_object=user_function_object,
                         name=DefinitionConstants.CRITERIA, code_type=code_type)
@@ -30,12 +30,17 @@ class CriteriaController(Plugin, PluginInterface):
         self.init_plugin_data(update=True)
         self._data_dict = {}
 
-    def calculate_and_store_results(self, param_dict):
-        '''
+    def _calculate_and_store_results(self, param_dict):
+        """
         :param param_dict:
         :return:
-        '''
+        """
+        self._logger.emit(LOGConstants.SCRIPT[0], "Calculating Criteria: " + param_dict["criteria"])
+
         sample_offset = self._get_sample_offset(param_dict)
+        if sample_offset is None:
+            return
+
         json_object = param_dict[PluginsParamDictDef.DYNASAUR_JSON]
         reduced_sample_offsets = self._reduce_sample_offset(json_object, sample_offset)
 
@@ -73,13 +78,13 @@ class CriteriaController(Plugin, PluginInterface):
                                                             OutputStringForPlugins.LIMITS: limits}})
 
     def write_CSV(self, directory, filename=None):
-        '''
+        """
         write csv file on the given path
 
         :param csv_file_dir:
         :param filename:
         :return:
-        '''
+        """
         if os.path.isdir(directory) is None:
             self._logger.emit(LOGConstants.ERROR[0], self._name + ": csv_file_dir is not a directory")
             return
@@ -111,13 +116,13 @@ class CriteriaController(Plugin, PluginInterface):
         self._logger.emit(LOGConstants.SCRIPT[0], self._name + LoggerSCRIPT.print_statements[6] + path)
 
     def get_data(self, part_of=None, criteria_type=None, criteria_name=None):
-        '''
+        """
         Get data from data dict
 
         :param:
 
         :return data dict with all data:
-        '''
+        """
         if part_of is None and criteria_type is None and criteria_name is None:
             return self._data_dict
 
