@@ -11,13 +11,13 @@ from ..calc.standard_functions import StandardFunction
 from ..utils.constants import LOGConstants, PluginsParamDictDef
 from ..utils.logger import ConsoleLogger
 from ..data.dynasaur_definitions import DynasaurDefinitions
-from ..data.DataContainer import DataContainer
+from ..data.data_container import DataContainer
 from ..data.vps import VPSData
 from ..data.madymo import MadymoData
 
 class Plugin(object):
     def __init__(self, path_to_def_file, path_def_file_id, data_source, name, user_function_object=None, volume_path=None, code_type="LS-DYNA"):
-        '''
+        """
         Initialization class constructor
 
         :param: calculation_procedure_def_file
@@ -28,7 +28,7 @@ class Plugin(object):
         :param: dynasaur definition
 
         :return:
-        '''
+        """
         self._logger = ConsoleLogger()
         self._dynasaur_definitions = DynasaurDefinitions(self._logger)
         self._dynasaur_definitions.read_def(path_to_def_file)
@@ -62,16 +62,15 @@ class Plugin(object):
         time.sleep(1)
 
     def _get_data_from_dynasaur_json(self, json_object, data_offsets):
-        '''
+        """
 
         :param json_object:
         :param data_offsets:
         :return:
-        '''
+        """
         if JsonConstants.FUNCTION in json_object.keys():  # expected name and params
             function_name = json_object[JsonConstants.FUNCTION][JsonConstants.NAME]
             parameter_def = json_object[JsonConstants.FUNCTION][JsonConstants.PARAM]
-
             param_dict = {}
             for key in parameter_def.keys():
                 if type(parameter_def[key]) is dict:  # step into recursion
@@ -125,10 +124,15 @@ class Plugin(object):
                 return StandardFunction.abs_addition(param_dict)
             elif function_name == StandardFunctionsDefinition.ABS_SUB_RES:
                 return StandardFunction.abs_subtraction_res(param_dict)
+            elif function_name == StandardFunctionsDefinition.TIME_OF_FIRST_NEGATIVE:
+                return StandardFunction.time_of_first_negative(param_dict)
             elif function_name == StandardFunctionsDefinition.ABS_MAX:
                 return StandardFunction.max(param_dict, absolute=True)
             elif function_name == StandardFunctionsDefinition.NIC:
-                return StandardFunction.NIC(param_dict, self._units)
+                return StandardFunction.NIC(a_t1=param_dict["a_T1"],
+                                            a_head=param_dict["a_head"],
+                                            time_=param_dict["time"],
+                                            units=self._units)
             elif function_name == StandardFunctionsDefinition.uBRIC:
                 return StandardFunction.uBRIC(param_dict, self._units)
             elif function_name == StandardFunctionsDefinition.ALL_HIC15_AIS3:
@@ -177,20 +181,20 @@ class Plugin(object):
             return self._data[data_type].get_data_of_defined_json(json_object, data_offsets)
 
     def _check_if_user_function(self, function_name):
-        '''
+        """
         :param function_name:
         :return bool:
-        '''
+        """
         attributes = inspect.getmembers(self._user_function, predicate=inspect.isfunction)
         if function_name in [att[0] for att in attributes]:
             return True
         return False
 
     def init_plugin_data(self, update):
-        '''
+        """
         :param update:
         :return:
-        '''
+        """
         if self._data is None or update:
             self._data = {data: DataContainer.get_data(data) for data in self._data_requirements}
             for data_name in self._data.keys():
@@ -204,13 +208,13 @@ class Plugin(object):
                     self._logger.emit(LOGConstants.ERROR[0], data_name + LoggerERROR.print_statements[2])
 
     def _reduce_sample_offset(self, json_object, sample_offsets):
-        '''
+        """
 
         :param json_object:
         :param data_offsets:
 
         :return sample:
-        '''
+        """
         self._get_data_from_json_reduce_samples(json_object)
         self._sample_types = list(set(self._sample_types))
         return_sample = []
@@ -221,13 +225,13 @@ class Plugin(object):
         return return_sample
 
     def _get_sample_offset(self, param_dict):
-        '''
+        """
         get sample offset defined between start and end time
 
         :param param_dict:
 
         :return sample offset:
-        '''
+        """
         start_time = param_dict[PluginsParamDictDef.START_TIME] if PluginsParamDictDef.START_TIME in param_dict \
                         and param_dict[PluginsParamDictDef.START_TIME] != "None" else None
         end_time = param_dict[PluginsParamDictDef.END_TIME] if PluginsParamDictDef.END_TIME in param_dict \
@@ -239,15 +243,20 @@ class Plugin(object):
                 continue
 
             if start_time is not None and end_time is not None:
-                if start_time >= end_time:
-                    # TODO: Discuss maybe brake
-                    self._logger.emit(LOGConstants.ERROR[0],
-                                      "End time is smaller or equal as start time! End time set to last value in time step list.")
-                    end_time = self._data[key].get_()[-1]
                 indices = np.argwhere(
                     (start_time * self._units.second() <= self._data[key].get_interpolated_time()) &
                     (self._data[key].get_interpolated_time() <= end_time * self._units.second()))
-            elif start_time is not None and end_time == None:
+                if len(indices) == 0:
+                    self._logger.emit(LOGConstants.ERROR[0],
+                                      "Check t_start, which was set to " + str(start_time * self._units.second()))
+                    return
+                if start_time >= end_time:
+                    end_time = self._data[key].get_()[-1]
+                    self._logger.emit(LOGConstants.ERROR[0],
+                                      "End time is smaller or equal as start time! End time set to " + str(end_time))
+                    return
+
+            elif start_time is not None and end_time is None:
                 indices = np.argwhere(start_time * self._units.second() <= self._data[key].get_interpolated_time())
 
             elif start_time is None and end_time is not None:
@@ -260,13 +269,13 @@ class Plugin(object):
         return sample_offsets
 
     def _get_data_from_json_reduce_samples(self, json_object):
-        '''
+        """
         get sample offset defined between start and end time
 
         :param json_object:
 
         :return sample offset:
-        '''
+        """
         if JsonConstants.FUNCTION in json_object.keys():  # expected name and params
             parameter_def = json_object[JsonConstants.FUNCTION][JsonConstants.PARAM]
 
@@ -291,20 +300,13 @@ class Plugin(object):
 
 class PluginInterface(metaclass=abc.ABCMeta):
 
-    # @abc.abstractmethod
-    # def _store_data_to_dict(self):
-    #     '''
-    #     Save the data object to the output.
-    #     :return:
-    #     '''
-
     @abc.abstractmethod
-    def calculate_and_store_results(self, param_dict):
-        '''
+    def _calculate_and_store_results(self, param_dict):
+        """
         :param param_dict:
         :return:
-        '''
+        """
 
     def calculate(self, param_dict):
         param_dict_data = self._dynasaur_definitions.get_param_dict_from_command(command=param_dict)
-        self.calculate_and_store_results(param_dict_data)
+        self._calculate_and_store_results(param_dict_data)
