@@ -216,6 +216,7 @@ class StandardFunctionsDefinition:
     HIC15 = "HIC_15"
     HIC36 = "HIC_36"
     BRIC = "BrIC"
+    TIME_OF_FIRST_NEGATIVE = "time_of_first_negative"
     A3MS = "a3ms"
     NIJ = "nij"
     VC = "vc"
@@ -273,7 +274,7 @@ class LOGConstants(object):
     READ_VOLUME = ("[READ VOLUME]", "grey")
     READ_DYNASAUR_DEF = ("[READ DYNASAUR DEF]", "green")
     DATA_PLUGIN = ("[DATA]", "white")
-    SCRIPT = ("[SCRIPT]", "cyan")
+    SCRIPT = ("[CALCULATION]", "cyan")
     INPUT = ("[USER INPUT]", "blue")
 
 
